@@ -14,11 +14,11 @@ pub mod blobmeta {
     #[derive(Clone, Debug, Deserialize, Serialize, PartialEq)]
     #[serde(deny_unknown_fields)]
     pub struct ListMetadataRequest {
-        /// Optionally filter which tags to return (defaults to all).
+        /// Optionally filters which tags to return (defaults to all).
         pub tags: Option<Vec<String>>,
 
-        /// Optionally filter which keys to return (defaults to all). [e.g. "filetype"]
-        pub meta_keys: Option<Vec<String>>,
+        /// Optionally filters which fields to return (defaults to all). [e.g. "filetype"]
+        pub fields: Option<Vec<String>>,
     }
 
     #[derive(Clone, Debug, Deserialize, Serialize, PartialEq)]
@@ -98,8 +98,7 @@ pub mod storage {
 }
 
 pub mod query {
-
-    use interface::SortOrder;
+    use interface::{ExpressionField, FieldValue, SortOrder};
 
     use super::*;
 
@@ -112,16 +111,12 @@ pub mod query {
         Tag { tag: String },
         /// Key/Value expression.
         ///
-        /// Evaluates to resolver items where the given key/value pair is present.
-        KeyValue { key: String, value: String },
-        /// HasKey expression.
+        /// Evaluates to resolver items where the given field/value pair is present.
+        Field { key: String, value: FieldValue },
+        /// HasField expression.
         ///
-        /// Evaluates to resolver items where the given key is present (in any key/value pair).
-        HasKey { key: String },
-        /// Parent expression.
-        ///
-        /// Evaluates to resolver items having the provided value as a parent.
-        Parent { parent: String },
+        /// Evaluates to resolver items where the given field is present.
+        HasField { key: String },
         /// And expression.
         ///
         /// Evaluates to the intersection of its two sub-expressions.
@@ -145,7 +140,7 @@ pub mod query {
         Empty,
     }
 
-    impl TryFrom<RawExpression> for Expression {
+    impl TryFrom<RawExpression> for Expression<ExpressionField> {
         type Error = anyhow::Error;
 
         fn try_from(value: RawExpression) -> Result<Self, Self::Error> {
@@ -169,10 +164,11 @@ pub mod query {
                         Box::new(Expression::try_from(*b)?),
                     ),
                 },
-                RawExpression::Parent { parent } => Self::Parent { parent },
-                RawExpression::HasKey { key } => Self::HasKey { key },
-                RawExpression::KeyValue { key, value } => Self::KeyValue { key, value },
-                RawExpression::Tag { tag } => Self::Tag { tag },
+                RawExpression::HasField { key } => Self::Field(ExpressionField::HasField { key }),
+                RawExpression::Field { key, value } => {
+                    Self::Field(ExpressionField::Field { key, value })
+                }
+                RawExpression::Tag { tag } => Self::Field(ExpressionField::Tag { tag }),
             };
 
             Ok(expr)
@@ -258,7 +254,7 @@ pub mod query {
 
 #[cfg(test)]
 mod tests {
-    use interface::Expression;
+    use interface::{Expression, ExpressionField};
 
     use super::query::RawExpression;
 
@@ -266,17 +262,11 @@ mod tests {
     fn mixed_expression_parsing() {
         let manual_expr = Expression::And {
             and: (
-                Box::new(Expression::Tag {
-                    tag: String::from("a"),
-                }),
+                Box::new(Expression::Field(ExpressionField::Tag { tag: "a".into() })),
                 Box::new(Expression::And {
                     and: (
-                        Box::new(Expression::Tag {
-                            tag: String::from("b"),
-                        }),
-                        Box::new(Expression::Tag {
-                            tag: String::from("c"),
-                        }),
+                        Box::new(Expression::Field(ExpressionField::Tag { tag: "b".into() })),
+                        Box::new(Expression::Field(ExpressionField::Tag { tag: "c".into() })),
                     ),
                 }),
             ),
